vortex\_detection module
======================================================

.. automodule:: IMTreatment.vortex_detection.vortex_detection
    :members:
    :undoc-members:
    :show-inheritance:
